@@ -62,7 +62,7 @@ setsim(nl, \"simoutput\") <- results")
 #'
 #' @param nl nl object
 #' @param metrics vector of strings defining metric columns for evaluation. Defaults to metrics of the experiment within the nl object
-#' @param funs dplyr::funs list with the summary metrics one wants to have for the sensitivity results
+#' @param funs list with the summary metrics for the sensitivity results
 #' @return analysis summary tibble
 #'
 #' @details
@@ -71,6 +71,7 @@ setsim(nl, \"simoutput\") <- results")
 #'
 #' analyze_nl calls different post-processing analysis functions, depending on the specified method in the simdesign object of the nl object.
 #'
+#'
 #' \strong{The following simdesign are currently supported:}
 #'
 #' \link[nlrx]{simdesign_ff}
@@ -124,7 +125,7 @@ setsim(nl, \"simoutput\") <- results")
 #' nl <- nl_sobol
 #'
 #' # Define aggregation measurements:
-#' myfuns <- dplyr::funs(mean, sd, min, max)
+#' myfuns <- list(mean=mean, sd=sd, min=min, max=max)
 #'
 #' # Calculate sensitivity indices:
 #' analyze_nl(nl, funs = myfuns)
@@ -135,7 +136,7 @@ setsim(nl, \"simoutput\") <- results")
 #' @export
 
 analyze_nl <- function(nl, metrics = getexp(nl, "metrics"),
-                       funs = dplyr::funs(mean)) {
+                       funs = list(mean = mean)) {
 
   ## Check if results have been attached:
   if (purrr::is_empty(getsim(nl, "simoutput"))) {
@@ -176,7 +177,7 @@ analyze_nl <- function(nl, metrics = getexp(nl, "metrics"),
 #' @description Analyze NetLogo simulation output of simdesign simple
 #' @param nl nl object
 #' @param metrics vector of strings defining metric columns for evaluation. Defaults to metrics of the experiment within the nl object
-#' @param funs dplyr::funs list with the summary metrics one wants to have for the sensitivity results
+#' @param funs list with the summary metrics for the sensitivity results
 #' @details
 #'
 #' The simdesign_simple analysis functions is not yet supported and will only print a warning message.
@@ -194,7 +195,7 @@ analyze_simple <- function(nl, metrics, funs) {
 #' @description Analyze NetLogo simulation output of simdesign full-factorial
 #' @param nl nl object
 #' @param metrics vector of strings defining metric columns for evaluation. Defaults to metrics of the experiment within the nl object
-#' @param funs dplyr::funs list with the summary metrics one wants to have for the sensitivity results
+#' @param funs list with the summary metrics for the sensitivity results
 #' @details
 #'
 #' The function calculates aggregated output metrics by dropping random seeds and aggregating values with the provided functions.
@@ -213,7 +214,7 @@ analyze_ff <- function(nl, metrics, funs) {
     dplyr::summarise_at(metrics, funs) %>%
     dplyr::ungroup()
 
-  ffagg <- tibble::as.tibble(ffagg)
+  ffagg <- tibble::as_tibble(ffagg)
 
   return(ffagg)
 }
@@ -225,7 +226,7 @@ analyze_ff <- function(nl, metrics, funs) {
 #' @description Analyze NetLogo simulation output of simdesign latin-hypercube
 #' @param nl nl object
 #' @param metrics vector of strings defining metric columns for evaluation. Defaults to metrics of the experiment within the nl object
-#' @param funs dplyr::funs list with the summary metrics one wants to have for the sensitivity results
+#' @param funs list with the summary metrics for the sensitivity results
 #' @details
 #'
 #' The function calculates aggregated output metrics by dropping random seeds and aggregating values with the provided functions.
@@ -244,7 +245,7 @@ analyze_lhs <- function(nl, metrics, funs) {
     dplyr::summarise_at(getexp(nl, "metrics"), funs) %>%
     dplyr::ungroup()
 
-  lhsagg <- tibble::as.tibble(lhsagg)
+  lhsagg <- tibble::as_tibble(lhsagg)
 
   return(lhsagg)
 }
@@ -256,7 +257,7 @@ analyze_lhs <- function(nl, metrics, funs) {
 #' @description Analyze NetLogo simulation output of simdesign sobol
 #' @param nl nl object
 #' @param metrics vector of strings defining metric columns for evaluation. Defaults to metrics of the experiment within the nl object
-#' @param funs dplyr::funs list with the summary metrics one wants to have for the sensitivity results
+#' @param funs list with the summary metrics for the sensitivity results
 #' @details
 #'
 #' The function calculates sobol sensitivity indices from the output results using the \link[sensitivity]{sensitivity} package.
@@ -297,7 +298,7 @@ analyze_sobol <- function(nl, metrics, funs) {
   }
   # Remove rownames
   rownames(sensindex) <- NULL
-  sensindex <- tibble::as.tibble(sensindex)
+  sensindex <- tibble::as_tibble(sensindex)
 
   return(sensindex)
 }
@@ -309,7 +310,7 @@ analyze_sobol <- function(nl, metrics, funs) {
 #' @description Analyze NetLogo simulation output of simdesign sobol2007
 #' @param nl nl object
 #' @param metrics vector of strings defining metric columns for evaluation. Defaults to metrics of the experiment within the nl object
-#' @param funs dplyr::funs list with the summary metrics one wants to have for the sensitivity results
+#' @param funs list with the summary metrics for the sensitivity results
 #' @details
 #'
 #' The function calculates sobol sensitivity indices from the output results using the \link[sensitivity]{sensitivity} package.
@@ -360,7 +361,7 @@ analyze_sobol2007 <- function(nl, metrics, funs) {
   }
   # Remove rownames
   rownames(sensindex) <- NULL
-  sensindex <- tibble::as.tibble(sensindex)
+  sensindex <- tibble::as_tibble(sensindex)
 
   return(sensindex)
 }
@@ -372,7 +373,7 @@ analyze_sobol2007 <- function(nl, metrics, funs) {
 #' @description Analyze NetLogo simulation output of simdesign soboljansen
 #' @param nl nl object
 #' @param metrics vector of strings defining metric columns for evaluation. Defaults to metrics of the experiment within the nl object
-#' @param funs dplyr::funs list with the summary metrics one wants to have for the sensitivity results
+#' @param funs list with the summary metrics for the sensitivity results
 #' @details
 #'
 #' The function calculates sobol sensitivity indices from the output results using the \link[sensitivity]{sensitivity} package.
@@ -422,7 +423,7 @@ analyze_soboljansen <- function(nl, metrics, funs) {
   }
   # Remove rownames
   rownames(sensindex) <- NULL
-  sensindex <- tibble::as.tibble(sensindex)
+  sensindex <- tibble::as_tibble(sensindex)
 
   return(sensindex)
 }
@@ -435,7 +436,7 @@ analyze_soboljansen <- function(nl, metrics, funs) {
 #' @description Analyze NetLogo simulation output of simdesign morris
 #' @param nl nl object
 #' @param metrics vector of strings defining metric columns for evaluation. Defaults to metrics of the experiment within the nl object
-#' @param funs dplyr::funs list with the summary metrics one wants to have for the sensitivity results
+#' @param funs list with the summary metrics for the sensitivity results
 #' @details
 #'
 #' The function calculates morris sensitivity indices from the output results using the \link[sensitivity]{sensitivity} package.
@@ -494,7 +495,7 @@ analyze_morris <- function(nl, metrics, funs) {
 
   # Remove rownames
   rownames(sensindex) <- NULL
-  sensindex <- tibble::as.tibble(sensindex)
+  sensindex <- tibble::as_tibble(sensindex)
 
   return(sensindex)
 }
@@ -506,7 +507,7 @@ analyze_morris <- function(nl, metrics, funs) {
 #' @description Analyze NetLogo simulation output of simdesign eFast
 #' @param nl nl object
 #' @param metrics vector of strings defining metric columns for evaluation. Defaults to metrics of the experiment within the nl object
-#' @param funs dplyr::funs list with the summary metrics one wants to have for the sensitivity results
+#' @param funs list with the summary metrics for the sensitivity results
 #' @details
 #'
 #' The function calculates eFast sensitivity indices from the output results using the \link[sensitivity]{sensitivity} package.
@@ -557,7 +558,7 @@ analyze_eFast <- function(nl, metrics, funs) {
   }
   # Remove rownames
   rownames(sensindex) <- NULL
-  sensindex <- tibble::as.tibble(sensindex)
+  sensindex <- tibble::as_tibble(sensindex)
 
   return(sensindex)
 }
